@@ -10,6 +10,7 @@ Copyright (C) 2010 Nick Leppänen Larsson <frals@frals.se>
 import os
 import sys
 import gettext
+import codecs
 
 import gtk
 import hildon
@@ -56,7 +57,11 @@ class fMMS_Viewer(hildon.Program):
 		self._parse_mms(fname, vbox)
 
 		pan.add_with_viewport(vbox)
-		self.window.add(pan)
+		
+		align = gtk.Alignment(1, 1, 1, 1)
+		align.set_padding(2, 2, 10, 10)
+		align.add(pan)
+		self.window.add(align)
 
 		if not self.cont.is_mms_read(fname) and self._direction == fMMSController.MSG_DIRECTION_IN:
 			self.cont.mark_mms_read(fname)
@@ -268,9 +273,9 @@ class fMMS_Viewer(hildon.Program):
 		timelabel.set_use_markup(True)
 		timelabel.set_alignment(1, 0.5)
 
-		topbox.pack_start(label, False, False, 20)
-		topbox.pack_start(namelabel, True, True, 0)
-		topbox.pack_end(timelabel, False, False, 10)
+		topbox.pack_start(label, False, False, 0)
+		topbox.pack_start(namelabel, True, True, 10)
+		topbox.pack_end(timelabel, False, False, 0)
 		
 		container.pack_start(topbox, False, False, 5)
 		sep = gtk.HSeparator()
@@ -282,7 +287,7 @@ class fMMS_Viewer(hildon.Program):
 		self.textview.set_editable(False)
 		self.textview.set_cursor_visible(False)
 		self.textview.set_wrap_mode(gtk.WRAP_WORD)
-		self.textview.set_justification(gtk.JUSTIFY_CENTER)
+		self.textview.set_justification(gtk.JUSTIFY_LEFT)
 		textbuffer = gtk.TextBuffer()
 		direction = self.cont.get_direction_mms(filename)
 		
@@ -310,7 +315,7 @@ class fMMS_Viewer(hildon.Program):
 			except Exception, e:
 				filetype = None
 				log.exception("%s %s", type(e), e)
-			
+
 			if isImage or ext == ".wbmp":
 				""" insert the image in an eventbox so we can get signals """
 				ebox = gtk.EventBox()
@@ -328,8 +333,13 @@ class fMMS_Viewer(hildon.Program):
 				container.add(ebox)
 				self.attachment = fnpath
 			elif isText or ext.startswith(".txt"):
-				fp = open(path + "/" + fname, 'r')
-				contents = fp.read()
+				try:
+					fp = codecs.open(path + "/" + fname, 'r', 'utf-8')
+					contents = fp.read()
+				except:
+					fp = codecs.open(path + "/" + fname, 'r', 'latin-1')
+					contents = fp.read()
+				
 				fp.close()
 				textbuffer.insert(textbuffer.get_end_iter(), contents)
 			elif name != "message" and name != "headers" and not ext.startswith(".smil") and filetype != "application/smil":
